# Hardware documentation

This folder contains PCB documentation like schematics.

The design is partially based on [Adafruit Feather M4 CAN](https://github.com/adafruit/Adafruit-Feather-M4-CAN-PCB).
Please support them by purchasing producs from [Adafruit](https://www.adafruit.com).


## License

All files in this folder are licensed under Creative Commons Attribution/Share-Alike license.
See [lincense.txt](license.txt) for details.
